@@ -496,6 +496,7 @@ add_inhibitor (GsmInhibitDialog *dialog,
 
         /* FIXME: get info from xid */
 
+        desktop_file = NULL;
         name = NULL;
         pixbuf = NULL;
         freeme = NULL;
@@ -602,6 +603,9 @@ add_inhibitor (GsmInhibitDialog *dialog,
         if (pixbuf != NULL) {
                 g_object_unref (pixbuf);
         }
+        if (desktop_file != NULL) {
+                egg_desktop_file_free (desktop_file);
+        }
 }
 
 static gboolean
@@ -997,6 +1001,11 @@ gsm_inhibit_dialog_dispose (GObject *object)
                 dialog->priv->inhibitors = NULL;
         }
 
+        if (dialog->priv->xml != NULL) {
+                g_object_unref (dialog->priv->xml);
+                dialog->priv->xml = NULL;
+        }
+
         G_OBJECT_CLASS (gsm_inhibit_dialog_parent_class)->dispose (object);
 }
 
